@@ -3,14 +3,14 @@ import json, xmlrpc.client
 __doc__ = "Module for getting/modifying data models in Odoo"
 
 class Odoo():
-  def __init__(self) -> None:
-    # self.url = 'https://little-unicorn.odoo.com'
-    # self.db = 'little-unicorn'
-    # self.models = xmlrpc.client.ServerProxy('{}/xmlrpc/2/object'.format(self.url))
-    # self.username = 'bbrandley@littleunicorn.com'
-    # self.password = "4Od0024!"
-    # self.common = xmlrpc.client.ServerProxy('{}/xmlrpc/2/common'.format(self.url))
-    # self.uid = self.common.authenticate(self.db, self.username, self.password, {})
+  def __init__(self, url, database, username, password) -> None:
+    self.url = url
+    self.db = database
+    self.models = xmlrpc.client.ServerProxy('{}/xmlrpc/2/object'.format(self.url))
+    self.username = username
+    self.password = password
+    self.common = xmlrpc.client.ServerProxy('{}/xmlrpc/2/common'.format(self.url))
+    self.uid = self.common.authenticate(self.db, self.username, self.password, {})
 
   def getObject(self, object, id):
     obj = self.models.execute_kw(self.db, self.uid, self.password, object, 'read', [id])
